@@ -1,4 +1,4 @@
-PopGplot <- function(values, colors=FALSE, span=0.1){
+PopGplot <- function(values, colors=FALSE, span=0.1, ylab="", xlab=""){
 
 
 if(colors[1]==FALSE){
@@ -9,7 +9,7 @@ ids <- 1:length(values[,1])
 #
 # plot first pop
 firstpop <- loess(values[,1]~ids, span=span)
-plot(predict(firstpop),type="l",xlab="window",ylab="value",col=colors[1],ylim=c(min(values),max(values)))
+plot(predict(firstpop),type="l",xlab=xlab,ylab=ylab,col=colors[1],ylim=c(min(values,na.rm=TRUE),max(values, na.rm=TRUE)),xaxt="n")
 
 if(dim(values)[2]>1){
 for(xx in 2:dim(values)[2]){
