@@ -187,17 +187,25 @@ for(xx in 1:npops){
 
    # adjacent <- apply(sitepairs,2,function(x){return(x[2]==(x[1]+1))})
 
-adjacent <- rep(1,n.segsites.pop-1)
-fill     <- n.segsites.pop - 1
-for (yy in 2:length(adjacent)) {
- adjacent[yy] <- adjacent[yy-1] + fill
- fill <- fill - 1  
+if(n.segsites.pop==2){
+
+	adjacent <- 1
+
+}else{
+	adjacent <- rep(1,n.segsites.pop-1)
+	fill     <- n.segsites.pop - 1
+	for (yy in 2:length(adjacent)) {
+ 	adjacent[yy] <- adjacent[yy-1] + fill
+ 	fill <- fill - 1  
+	}
+
 }
    
    ZA[xx]   <- sum(res[adjacent])/(n.segsites.pop-1)
    ZZ[xx]   <- ZA[xx] - znsvek[xx]
  
 
+
 }# End of iteration over pops
 
  #reslist           <- as.matrix(reslist)
